function varargout = Caract_magnitudes(varargin)
% CARACT_MAGNITUDES M-file for Caract_magnitudes.fig
%      CARACT_MAGNITUDES, by itself, creates a new CARACT_MAGNITUDES or raises the existing
%      singleton*.
%
%      H = CARACT_MAGNITUDES returns the handle to a new CARACT_MAGNITUDES or the handle to
%      the existing singleton*.
%
%      CARACT_MAGNITUDES('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in CARACT_MAGNITUDES.M with the given input arguments.
%
%      CARACT_MAGNITUDES('Property','Value',...) creates a new CARACT_MAGNITUDES or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Caract_magnitudes_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Caract_magnitudes_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES
% Copyright 2002-2003 The MathWorks, Inc.
% Edit the above text to modify the response to help Caract_magnitudes
% Last Modified by GUIDE v2.5 12-Dec-2005 23:50:23

%DEFINICIÓN DE FUNCIÓN
%Función que nos permite crear la Caract_magnitudes

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Caract_magnitudes_OpeningFcn, ...
                   'gui_OutputFcn',  @Caract_magnitudes_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Caract_magnitudes is made visible.
function Caract_magnitudes_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Caract_magnitudes (see VARARGIN)
% Choose default command line output for Caract_magnitudes
handles.output = hObject;
%Por defecto ponemos una imagen en la Caract_magnitudes
A=imread('logo','jpeg');
axes(handles.Figura_axes)
image(A);

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Caract_magnitudes wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Caract_magnitudes_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in ayuda_push.
function ayuda_push_Callback(hObject, eventdata, handles)
% hObject    handle to ayuda_push (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
helpdlg('AYUDA: Pulse Siguiente para comenzar el procesado','AYUDA');



% --- Executes on button press in siguiente_push.
function siguiente_push_Callback(hObject, eventdata, handles)
% hObject    handle to siguiente_push (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close all
clear all
procesado;



% --- Executes on button press in Cancelar_push.
function Cancelar_push_Callback(hObject, eventdata, handles)
% hObject    handle to Cancelar_push (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
closereq

